============
Installation
============

To install the `pythermalcomfort` package, follow the steps below:

Using pip
=========

You can install the package from PyPI using pip. Open your terminal and run:

.. code-block:: bash

    pip install pythermalcomfort

From Source
===========

To install the package from the source, clone the repository and install it using pip:

.. code-block:: bash

    git clone https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort.git
    cd pythermalcomfort
    pip install .

Dependencies
============

The package requires the following dependencies, which will be installed automatically with pip:

- numpy
- scipy
- pandas

Verifying Installation
======================

To verify that the package is installed correctly, you can run:

.. code-block:: python

    import pythermalcomfort

    print(pythermalcomfort.__version__)

This should print the version of the `pythermalcomfort` package installed on your system.
